@@ -5,6 +5,9 @@
 #	Copyright (C) 2003, Alessandro Zummo.
 #	You may distribute this file under the terms of the Artistic
 #	License, as specified in the README file.
+#
+# $Id: ZirePhoto.pm,v 1.9 2005/07/30 01:37:44 christophe Exp $
+
 
 use strict;
 package Palm::ZirePhoto;
@@ -14,7 +17,7 @@ use Palm::StdAppInfo();
 use vars qw( $VERSION @ISA );
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.011_01';
+$VERSION = do { my @r = (q$Revision: 1.9 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @ISA = qw( Palm::StdAppInfo Palm::Raw );
 
@@ -230,17 +233,9 @@ sub ParseAlbum
 
 __END__
 
-=head1 SOURCE CONTROL
-
-The source is in Github:
-
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
 =head1 AUTHOR
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
-
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Alessandro Zummo E<lt>a.zummo@towertech.itE<gt>
 
 =head1 SEE ALSO
 
